Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(612)

Unified Diff: net/proxy/proxy_server.h

Issue 149191: Whenever proxy configurations contain socks and http/https/ftp proxies, socks... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: adding disabled win test Created 11 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/proxy/proxy_server.h
===================================================================
--- net/proxy/proxy_server.h (revision 20189)
+++ net/proxy/proxy_server.h (working copy)
@@ -64,8 +64,8 @@
// Parse from an input with format:
// [<scheme>"://"]<server>[":"<port>]
//
// Both <scheme> and <port> are optional. If <scheme> is omitted, it will
// be assumed as "http". If <port> is omitted, it will be assumed as
// the default port for the chosen scheme (80 for "http", 1080 for "socks").
//
// If parsing fails the instance will be set to invalid.
@@ -77,9 +77,10 @@
// "http://foopy:17" {scheme=HTTP, host="foopy", port=17}
// "direct://" {scheme=DIRECT}
// "foopy:X" INVALID -- bad port.
- static ProxyServer FromURI(const std::string& uri);
+ static ProxyServer FromURI(const std::string& uri, Scheme default_scheme);
static ProxyServer FromURI(std::string::const_iterator uri_begin,
- std::string::const_iterator uri_end);
+ std::string::const_iterator uri_end,
+ Scheme default_scheme);
// Format as a URI string. This does the reverse of FromURI.
std::string ToURI() const;
@@ -64,8 +64,8 @@
// [<scheme>"://"]<server>[":"<port>]
//
- // Both <scheme> and <port> are optional. If <scheme> is omitted, it will
- // be assumed as "http". If <port> is omitted, it will be assumed as
+ // Both <scheme> and <port> are optional. If <scheme> is omitted, it will be
+ // assumed as |default_scheme|. If <port> is omitted, it will be assumed as
// the default port for the chosen scheme (80 for "http", 1080 for "socks").
//

Powered by Google App Engine
This is Rietveld 408576698